.. _spkg_calver:

calver: Setuptools extension for CalVer package versions
========================================================

Description
-----------

Setuptools extension for CalVer package versions

License
-------

Upstream Contact
----------------

https://pypi.org/project/calver/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2025.4.17

version_requirements.txt::

    calver

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install calver

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i calver

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add py3-calver

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-calver

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install calver

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/py-calver

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge calver

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-calver

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-calver

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python-calver

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-calver


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
